package com.ywt.mg.domain.models.enums;

/**
 * 处方单扩展状态（位运算）
 */
public enum PrescriptionInfoExtStatusEnum {

    IsCheckIn("已报到", 1),                 // 1
    IsSendOut("已发药", 1 << 1),            // 2
    IsPrint("已打印发票", 1 << 2),          // 4
    OtherFee("是否有其它付费", 1 << 3),      // 8
    PrintInjection("打印注射单", 1 << 4),   // 16
    PresNoPass("不通过", 1 << 5),           // 32
    Evaluate("已评价", 1 << 6),             // 64
    ExistInjection("是否有注射药品", 1 << 7),// 128
    PrintPres("打印处方筏", 1 << 8),         // 256
    Delivered("已配送", 1 << 9);         // 512

    private final String displayName;

    private final int value;

    PrescriptionInfoExtStatusEnum(String displayName, int value) {
        this.displayName = displayName;
        this.value = value;
    }

    public String getDisplayName() {
        return displayName;
    }

    public int getValue() {
        return value;
    }

    public static String getDisplayName(int value) {
        for (PrescriptionInfoExtStatusEnum e : PrescriptionInfoExtStatusEnum.values()) {
            if ((e.getValue() & value) == e.getValue() && e.getValue() <= value && (e.getValue() * 2) > value) {
                return e.displayName;
            }
        }
        return "";
    }

    public static boolean checkDelivered(Integer value) {
        if (value == null) {
            return false;
        }
        value = value.intValue();
        int deliveredValue = Delivered.getValue();
        if ((deliveredValue & value) == deliveredValue && deliveredValue <= value && (deliveredValue * 2) > value) {
            return true;
        }
        return false;
    }
}
